@@ -45,10 +45,10 @@ engine_jack_test (
   GtkWindow * win);
 
 /**
- * Zero's out the output buffers.
+ * Refreshes the list of external ports.
  */
 void
-engine_jack_clear_output_buffers (
+engine_jack_rescan_ports (
   AudioEngine * self);
 
 /**
@@ -68,6 +68,14 @@ engine_jack_set_transport_type (
   AudioEngine * self,
   AudioEngineJackTransportType type);
 
+/**
+ * Fills the external out bufs.
+ */
+void
+engine_jack_fill_out_bufs (
+  AudioEngine * self,
+  int           nframes);
+
 /**
  * Sets up the MIDI engine to use jack.
  *
