@@ -110,6 +110,7 @@ region_type_bitvals[] =
   { .name = "midi", .offset =  0, .bits =  1 },
   { .name = "audio", .offset =  1, .bits =  1 },
   { .name = "automation", .offset = 2, .bits = 1 },
+  { .name = "chord", .offset = 3, .bits = 1 },
 };
 
 /**
@@ -370,7 +371,7 @@ static const cyaml_schema_field_t
     "muted", CYAML_FLAG_DEFAULT,
     Region, muted),
   CYAML_FIELD_SEQUENCE_COUNT (
-    "midi_notes", CYAML_FLAG_DEFAULT,
+    "midi_notes", CYAML_FLAG_POINTER,
     Region, midi_notes, num_midi_notes,
     &midi_note_schema, 0, CYAML_UNLIMITED),
 	CYAML_FIELD_INT (
@@ -380,13 +381,17 @@ static const cyaml_schema_field_t
     "lane_pos", CYAML_FLAG_DEFAULT,
     Region, lane_pos),
   CYAML_FIELD_SEQUENCE_COUNT (
-    "aps", CYAML_FLAG_DEFAULT,
+    "aps", CYAML_FLAG_POINTER,
     Region, aps, num_aps,
     &automation_point_schema, 0, CYAML_UNLIMITED),
   CYAML_FIELD_SEQUENCE_COUNT (
-    "acs", CYAML_FLAG_DEFAULT,
+    "acs", CYAML_FLAG_POINTER,
     Region, acs, num_acs,
     &automation_curve_schema, 0, CYAML_UNLIMITED),
+  CYAML_FIELD_SEQUENCE_COUNT (
+    "chord_objects", CYAML_FLAG_POINTER,
+    Region, chord_objects, num_chord_objects,
+    &chord_object_schema, 0, CYAML_UNLIMITED),
 
 	CYAML_FIELD_END
 };
@@ -475,6 +480,13 @@ region_unsplit (
   Region *         r2,
   Region **        region);
 
+/**
+ * Print region info for debugging.
+ */
+void
+region_print (
+  const Region * region);
+
 /**
  * Returns the MidiNote matching the properties of
  * the given MidiNote.
@@ -553,6 +565,15 @@ Track *
 region_get_track (
   Region * region);
 
+/**
+ * Sets the Track position to the Region and all its
+ * members recursively.
+ */
+void
+region_set_track_pos (
+  Region *  region,
+  const int pos);
+
 /**
  * Returns the number of loops in the region,
  * optionally including incomplete ones.
