@@ -29,6 +29,7 @@
 #include "audio/automation_tracklist.h"
 #include "audio/channel.h"
 #include "audio/chord_object.h"
+#include "audio/marker.h"
 #include "audio/region.h"
 #include "audio/scale.h"
 #include "audio/scale_object.h"
@@ -310,6 +311,9 @@ track_fields_schema[] =
     Track, type, track_type_strings,
     CYAML_ARRAY_LEN (track_type_strings)),
 	CYAML_FIELD_INT (
+    "pos", CYAML_FLAG_DEFAULT,
+    Track, pos),
+	CYAML_FIELD_INT (
     "lanes_visible", CYAML_FLAG_DEFAULT,
     Track, lanes_visible),
 	CYAML_FIELD_INT (
@@ -337,17 +341,21 @@ track_fields_schema[] =
     "color", CYAML_FLAG_DEFAULT,
     Track, color, gdk_rgba_fields_schema),
   CYAML_FIELD_SEQUENCE_COUNT (
-    "lanes", CYAML_FLAG_DEFAULT,
+    "lanes", CYAML_FLAG_POINTER,
     Track, lanes, num_lanes,
     &track_lane_schema, 0, CYAML_UNLIMITED),
   CYAML_FIELD_SEQUENCE_COUNT (
-    "chord_regions", CYAML_FLAG_DEFAULT,
+    "chord_regions", CYAML_FLAG_POINTER,
     Track, chord_regions, num_chord_regions,
     &region_schema, 0, CYAML_UNLIMITED),
   CYAML_FIELD_SEQUENCE_COUNT (
-    "scales", CYAML_FLAG_DEFAULT,
+    "scales", CYAML_FLAG_POINTER,
     Track, scales, num_scales,
     &scale_object_schema, 0, CYAML_UNLIMITED),
+  CYAML_FIELD_SEQUENCE_COUNT (
+    "markers", CYAML_FLAG_POINTER,
+    Track, markers, num_markers,
+    &marker_schema, 0, CYAML_UNLIMITED),
   CYAML_FIELD_MAPPING_PTR (
     "channel",
     CYAML_FLAG_DEFAULT | CYAML_FLAG_OPTIONAL,
@@ -357,6 +365,14 @@ track_fields_schema[] =
     "automation_tracklist", CYAML_FLAG_DEFAULT,
     Track, automation_tracklist,
     automation_tracklist_fields_schema),
+  CYAML_FIELD_ENUM (
+    "in_signal_type", CYAML_FLAG_DEFAULT,
+    Track, in_signal_type, port_type_strings,
+    CYAML_ARRAY_LEN (port_type_strings)),
+  CYAML_FIELD_ENUM (
+    "out_signal_type", CYAML_FLAG_DEFAULT,
+    Track, out_signal_type, port_type_strings,
+    CYAML_ARRAY_LEN (port_type_strings)),
 
 	CYAML_FIELD_END
 };
@@ -467,6 +483,20 @@ track_add_region (
   int               lane_pos,
   int               gen_name);
 
+/**
+ * Appends the Track to the selections.
+ *
+ * @param exclusive Select only this track.
+ * @param fire_events Fire events to update the
+ *   UI.
+ */
+void
+track_select (
+  Track * self,
+  int     select,
+  int     exclusive,
+  int     fire_events);
+
 /**
  * Removes the region from the track.
  *
