@@ -32,22 +32,22 @@ G_DECLARE_FINAL_TYPE (InspectorTrackWidget,
 
 typedef struct TracklistSelections
   TracklistSelections;
-typedef struct _InstrumentTrackInfoExpanderWidget
-  InstrumentTrackInfoExpanderWidget;
+typedef struct _TrackPropertiesExpanderWidget
+  TrackPropertiesExpanderWidget;
 typedef struct _PortsExpanderWidget
   PortsExpanderWidget;
+typedef struct _TrackInputExpanderWidget
+  TrackInputExpanderWidget;
 
 typedef struct _InspectorTrackWidget
 {
   GtkBox             parent_instance;
-  InstrumentTrackInfoExpanderWidget *
+  TrackPropertiesExpanderWidget *
     instrument_track_info;
 
-  PortsExpanderWidget * prefader_sends;
-  PortsExpanderWidget * postfader_sends;
-  PortsExpanderWidget * stereo_in;
-  PortsExpanderWidget * midi_in;
-  PortsExpanderWidget * midi_out;
+  TrackInputExpanderWidget * inputs;
+
+  PortsExpanderWidget * sends;
 } InspectorTrackWidget;
 
 void
