@@ -154,14 +154,6 @@ typedef struct _TrackWidgetClass
 TrackWidget *
 track_widget_new (Track * track);
 
-/**
- * @param select 1 to select, 0 to unselect.
- */
-void
-track_widget_select (
-  TrackWidget * self,
-  int           select);
-
 /**
  * Sets the Track name on the TrackWidget.
  */
