@@ -21,10 +21,24 @@ import os
 import os.path
 import sys
 
+os.chdir(os.getenv('MESON_SOURCE_ROOT', '.'))
+
+potfiles = open (
+  'po/POTFILES', 'w')
+
+count = 0
 for path in ['inc', 'src', 'resources', 'data']:
   for dirpath, dirnames, filenames in os.walk(path):
     for filename in [
       f for f in filenames if f.endswith(".c") or
       f.endswith(".h") or f.endswith(".ui") or
       f.endswith(".desktop.in")]:
-        print(os.path.join(dirpath, filename))
+        str = os.path.join(dirpath, filename)
+        potfiles.write (str + '\n')
+        count = count + 1
+
+print (
+  "wrote {} entries to {}".format (
+    count, potfiles.name))
+
+potfiles.close ()
