@@ -231,11 +231,15 @@ activate_about (GSimpleAction *action,
       NULL
     };
   char * translators =
-      "Alexandros Theodotou <alex@zrythm.org>\n"
+      "Alexandros Theodotou\n"
       "Nicolas Faure <sub26nico@laposte.net>\n"
-      "Waui <wau-wau@tutanota.de>\n"
+      "Olivier Humbert <trebmuh@tuxfamily.org>\n"
+      "Waui\n"
       "Allan Nordhøy <epost@anotheragency.no>\n"
-      "WaldiS <admin@sto.ugu.pl>";
+      "WaldiS\n"
+      "Silvério Santos\n"
+      "Swann Martinet";
+
   char * version =
     zrythm_get_version (1);
 
@@ -534,7 +538,7 @@ activate_save (GSimpleAction *action,
    g_message ("%s project dir", PROJECT->dir);
 
    char * dir = g_strdup (PROJECT->dir);
-   project_save (dir);
+   project_save (PROJECT, dir);
    g_free (dir);
 }
 
@@ -581,7 +585,7 @@ activate_save_as (GSimpleAction *action,
 
       filename =
         gtk_file_chooser_get_filename (chooser);
-      project_save (filename);
+      project_save (PROJECT, filename);
       g_free (filename);
     }
 
@@ -616,8 +620,8 @@ activate_export_as (GSimpleAction *action,
     {
       ui_show_error_message (
         MAIN_WINDOW,
-        _("Project doesn't have a path yet. Please \
-save the project before exporting."));
+        _("Project doesn't have a path yet. Please "
+          "save the project before exporting."));
     }
 }
 
@@ -694,7 +698,7 @@ on_timeline_clipboard_received (
     timeline_selections_deserialize (text);
   timeline_selections_post_deserialize (ts);
   g_message ("printing deserialized");
-  timeline_selections_print (ts);
+  timeline_selections_print_yaml (ts);
 
   if (MAIN_WINDOW->last_focused ==
       GTK_WIDGET (MW_TIMELINE))
