@@ -118,6 +118,17 @@ get_y_normalized (
     }
 }
 
+/**
+ * Updates the frames of each position in each child
+ * of the AutomationCurve recursively.
+ */
+void
+automation_curve_update_frames (
+  AutomationCurve * self)
+{
+  position_update_frames (&self->pos);
+}
+
 /**
  * The function to return a point on the curve.
  *
