@@ -106,14 +106,15 @@ init_audio (
 {
   g_message ("initializing audio...");
 
+  control_room_init (CONTROL_ROOM, loading);
+
   if (loading)
     {
       /*stereo_ports_init_loaded (self->stereo_in);*/
-      stereo_ports_init_loaded (self->monitor_out);
+      /*stereo_ports_init_loaded (self->monitor_out);*/
     }
   else
     {
-      control_room_init (CONTROL_ROOM);
     }
 }
 
@@ -264,11 +265,6 @@ engine_init (
       break;
     }
 
-#ifdef HAVE_JACK
-  if (self->audio_backend == AUDIO_BACKEND_JACK)
-    engine_jack_activate (self);
-#endif
-
   self->buf_size_set = false;
 
   metronome_init (METRONOME);
@@ -280,6 +276,40 @@ engine_init (
     self->control_room.monitor_fader.stereo_in, 1);
 }
 
+/**
+ * Activates the audio engine to start receiving
+ * events.
+ */
+void
+engine_activate (
+  AudioEngine * self)
+{
+#ifdef HAVE_JACK
+  if (self->audio_backend == AUDIO_BACKEND_JACK)
+    engine_jack_activate (self);
+#endif
+}
+
+/**
+ * Returns 1 if the port is an engine port or
+ * control room port, otherwise 0.
+ */
+int
+engine_is_port_own (
+  AudioEngine * self,
+  const Port *  port)
+{
+  return
+    port ==
+      CONTROL_ROOM->monitor_fader.stereo_in->l ||
+    port ==
+      CONTROL_ROOM->monitor_fader.stereo_in->r ||
+    port ==
+      CONTROL_ROOM->monitor_fader.stereo_out->l ||
+    port ==
+      CONTROL_ROOM->monitor_fader.stereo_out->r;
+}
+
 void
 engine_realloc_port_buffers (
   AudioEngine * self,
@@ -823,12 +853,6 @@ engine_post_process (
       self->panic = 0;
     }
 
-  /* already processed recording start */
-  /*if (IS_TRANSPORT_ROLLING && TRANSPORT->starting_recording)*/
-    /*{*/
-      /*TRANSPORT->starting_recording = 0;*/
-    /*}*/
-
   /* move the playhead if rolling and not
    * pre-rolling */
   if (IS_TRANSPORT_ROLLING &&
@@ -846,17 +870,15 @@ engine_post_process (
         }
     }
 
+  /* update max time taken (for calculating DSP
+   * %) */
   AUDIO_ENGINE->last_time_taken =
     g_get_monotonic_time () -
     AUDIO_ENGINE->last_time_taken;
-  /*g_message ("last time taken: %ld");*/
   if (AUDIO_ENGINE->max_time_taken <
       AUDIO_ENGINE->last_time_taken)
     AUDIO_ENGINE->max_time_taken =
       AUDIO_ENGINE->last_time_taken;
-  /*g_message ("last time %ld, max time %ld",*/
-             /*AUDIO_ENGINE->last_time_taken,*/
-             /*AUDIO_ENGINE->max_time_taken);*/
 }
 
 /**
