@@ -27,6 +27,43 @@
 
 #include <glib/gi18n.h>
 
+/**
+ * Inits a PassthroughProcessor after loading a
+ * project.
+ */
+void
+passthrough_processor_init_loaded (
+  PassthroughProcessor * self)
+{
+  switch (self->type)
+    {
+    case PP_TYPE_AUDIO_CHANNEL:
+      port_set_owner_prefader (
+        self->stereo_in->l, self);
+      port_set_owner_prefader (
+        self->stereo_in->r, self);
+      port_set_owner_prefader (
+        self->stereo_out->l, self);
+      port_set_owner_prefader (
+        self->stereo_out->r, self);
+      break;
+    case PP_TYPE_MIDI_CHANNEL:
+      self->midi_in->midi_events =
+        midi_events_new (
+          self->midi_in);
+      port_set_owner_prefader (
+        self->midi_in, self);
+      self->midi_out->midi_events =
+        midi_events_new (
+          self->midi_out);
+      port_set_owner_prefader (
+        self->midi_out, self);
+      break;
+    default:
+      break;
+    }
+}
+
 /**
  * Inits passthrough_processor to default values.
  *
