@@ -81,12 +81,12 @@ port_init_loaded (Port * this)
   /* find plugin and track */
   SET_FIELDS_FROM_ID ((&this->identifier),this);
 
-
   PortIdentifier * id;
   for (int i = 0; i < this->num_srcs; i++)
     {
       id = &this->src_ids[i];
-      this->srcs[i] = port_find_from_identifier (id);
+      this->srcs[i] =
+        port_find_from_identifier (id);
       g_warn_if_fail (this->srcs[i]);
     }
   for (int i = 0; i < this->num_dests; i++)
@@ -96,6 +96,12 @@ port_init_loaded (Port * this)
         port_find_from_identifier (id);
       g_warn_if_fail (this->dests[i]);
     }
+
+  /* connect to backend if flag set */
+  if (port_is_exposed_to_backend (this))
+    {
+      port_set_expose_to_backend (this, 1);
+    }
 }
 
 /**
@@ -179,7 +185,9 @@ port_find_from_identifier (
         {
         case TYPE_EVENT:
           if (id->flow == FLOW_OUTPUT)
-            { /* TODO */ }
+            {
+              return ch->midi_out;
+            }
           else if (id->flow == FLOW_INPUT)
             {
               if (id->flags & PORT_FLAG_PIANO_ROLL)
@@ -215,21 +223,41 @@ port_find_from_identifier (
       g_warn_if_fail (tr);
       ch = tr->channel;
       g_warn_if_fail (ch);
-      if (id->flow == FLOW_OUTPUT)
+      switch (id->type)
         {
-          if (id->flags & PORT_FLAG_STEREO_L)
-            return ch->fader.stereo_out->l;
-          else if (id->flags &
-                     PORT_FLAG_STEREO_R)
-            return ch->fader.stereo_out->r;
-        }
-      else if (id->flow == FLOW_INPUT)
-        {
-          if (id->flags & PORT_FLAG_STEREO_L)
-            return ch->fader.stereo_in->r;
-          else if (id->flags &
-                     PORT_FLAG_STEREO_R)
-            return ch->fader.stereo_in->r;
+        case TYPE_EVENT:
+          switch (id->flow)
+            {
+            case FLOW_INPUT:
+              return ch->fader.midi_in;
+              break;
+            case FLOW_OUTPUT:
+              return ch->fader.midi_out;
+              break;
+            default:
+              break;
+            }
+          break;
+        case TYPE_AUDIO:
+          if (id->flow == FLOW_OUTPUT)
+            {
+              if (id->flags & PORT_FLAG_STEREO_L)
+                return ch->fader.stereo_out->l;
+              else if (id->flags &
+                         PORT_FLAG_STEREO_R)
+                return ch->fader.stereo_out->r;
+            }
+          else if (id->flow == FLOW_INPUT)
+            {
+              if (id->flags & PORT_FLAG_STEREO_L)
+                return ch->fader.stereo_in->l;
+              else if (id->flags &
+                         PORT_FLAG_STEREO_R)
+                return ch->fader.stereo_in->r;
+            }
+          break;
+        default:
+          break;
         }
       break;
     case PORT_OWNER_TYPE_PREFADER:
@@ -237,21 +265,41 @@ port_find_from_identifier (
       g_warn_if_fail (tr);
       ch = tr->channel;
       g_warn_if_fail (ch);
-      if (id->flow == FLOW_OUTPUT)
+      switch (id->type)
         {
-          if (id->flags & PORT_FLAG_STEREO_L)
-            return ch->prefader.stereo_out->l;
-          else if (id->flags &
-                     PORT_FLAG_STEREO_R)
-            return ch->prefader.stereo_out->r;
-        }
-      else if (id->flow == FLOW_INPUT)
-        {
-          if (id->flags & PORT_FLAG_STEREO_L)
-            return ch->prefader.stereo_in->l;
-          else if (id->flags &
-                     PORT_FLAG_STEREO_R)
-            return ch->prefader.stereo_in->r;
+        case TYPE_EVENT:
+          switch (id->flow)
+            {
+            case FLOW_INPUT:
+              return ch->prefader.midi_in;
+              break;
+            case FLOW_OUTPUT:
+              return ch->prefader.midi_out;
+              break;
+            default:
+              break;
+            }
+          break;
+        case TYPE_AUDIO:
+          if (id->flow == FLOW_OUTPUT)
+            {
+              if (id->flags & PORT_FLAG_STEREO_L)
+                return ch->prefader.stereo_out->l;
+              else if (id->flags &
+                         PORT_FLAG_STEREO_R)
+                return ch->prefader.stereo_out->r;
+            }
+          else if (id->flow == FLOW_INPUT)
+            {
+              if (id->flags & PORT_FLAG_STEREO_L)
+                return ch->prefader.stereo_in->l;
+              else if (id->flags &
+                         PORT_FLAG_STEREO_R)
+                return ch->prefader.stereo_in->r;
+            }
+          break;
+        default:
+          break;
         }
       break;
     case PORT_OWNER_TYPE_SAMPLE_PROCESSOR:
@@ -613,8 +661,7 @@ port_connect (
 int
 port_disconnect (Port * src, Port * dest)
 {
-  if (!src || !dest)
-    g_warn_if_reached ();
+  g_warn_if_fail (src && dest);
 
   int pos = -1;
   /* disconnect dest from src */
