@@ -183,6 +183,8 @@ region_init_loaded (Region * self)
             mn->region = self;
             midi_note_init_loaded (mn);
           }
+        self->midi_notes_size =
+          self->num_midi_notes;
       }
       break;
     case REGION_TYPE_CHORD:
@@ -194,11 +196,26 @@ region_init_loaded (Region * self)
             chord = self->chord_objects[i];
             chord_object_init_loaded (chord);
           }
+        self->chord_objects_size =
+          self->num_chord_objects;
         }
       break;
     case REGION_TYPE_AUTOMATION:
       {
-        /* TODO */
+        AutomationPoint * ap;
+        AutomationCurve * ac;
+        for (i = 0; i < self->num_aps; i++)
+          {
+            ap = self->aps[i];
+            automation_point_init_loaded (ap);
+          }
+        for (i = 0; i < self->num_acs; i++)
+          {
+            ac = self->acs[i];
+            automation_curve_init_loaded (ac);
+          }
+        self->aps_size =
+          self->num_aps;
       }
       break;
     }
@@ -462,6 +479,23 @@ region_update_frames (
 
 }
 
+ARRANGER_OBJ_DECLARE_RESET_COUNTERPART (
+  Region, region)
+{
+  Region * src =
+    reset_trans ?
+      region_get_main_region (region) :
+      region_get_main_trans_region (region);
+  Region * dest =
+    reset_trans ?
+      region_get_main_trans_region (region) :
+      region_get_main_region (region);
+
+  position_set_to_pos (
+    &dest->start_pos, &src->start_pos);
+  position_set_to_pos (
+    &dest->end_pos, &src->end_pos);
+}
 
 /**
  * Returns the length of the loop in ticks.
@@ -507,6 +541,37 @@ ARRANGER_OBJ_DECLARE_VALIDATE_POS (
       pos, &region->start_pos);
 }
 
+/**
+ * Sets the Track position to the Region and all its
+ * members recursively.
+ */
+void
+region_set_track_pos (
+  Region *  region,
+  const int pos)
+{
+  ARRANGER_OBJ_SET_PRIMITIVE_VAL (
+    Region, region, track_pos, pos, AO_UPDATE_ALL);
+}
+
+/**
+ * Print region info for debugging.
+ */
+void
+region_print (
+  const Region * self)
+{
+  char * str =
+    g_strdup_printf (
+      "%s [%s] - track pos %d - lane pos %d",
+      self->name,
+      region_type_bitvals[self->type].name,
+      self->track_pos,
+      self->lane_pos);
+  g_message ("%s", str);
+  g_free (str);
+}
+
 /**
  * Setter.
  */
