@@ -65,12 +65,14 @@ track_init_loaded (Track * track)
   for (i = 0; i < track->num_scales; i++)
     {
       scale = track->scales[i];
+      scale->track = track;
       scale_object_init_loaded (scale);
     }
   Marker * marker;
   for (i = 0; i < track->num_markers; i++)
     {
       marker = track->markers[i];
+      marker->track = track;
       marker_init_loaded (marker);
     }
 
@@ -289,6 +291,90 @@ track_clone (Track * track)
   return new_track;
 }
 
+/**
+ * Appends the Track to the selections.
+ *
+ * @param exclusive Select only this track.
+ * @param fire_events Fire events to update the
+ *   UI.
+ */
+void
+track_select (
+  Track * self,
+  int     select,
+  int     exclusive,
+  int     fire_events)
+{
+  if (select)
+    {
+      if (exclusive)
+        {
+          tracklist_selections_select_single (
+            TRACKLIST_SELECTIONS, self);
+        }
+      else
+        {
+          tracklist_selections_add_track (
+            TRACKLIST_SELECTIONS, self);
+        }
+    }
+  else
+    {
+      tracklist_selections_remove_track (
+        TRACKLIST_SELECTIONS,
+        self);
+    }
+
+  /* auto-set recording mode */
+  Channel * ch = self->channel;
+  switch (self->type)
+    {
+    case TRACK_TYPE_INSTRUMENT:
+    case TRACK_TYPE_AUDIO:
+    case TRACK_TYPE_MIDI:
+      g_warn_if_fail (ch);
+      g_message (
+        "%sselecting track %s, recording %d sa %d",
+        select ? "" : "de",
+        self->name,
+        self->recording,
+        ch->record_set_automatically);
+      /* if selecting the track and recording is not already
+       * on, turn these on */
+      if (select && !self->recording)
+        {
+          track_set_recording (self, 1);
+          ch->record_set_automatically = 1;
+        }
+      /* if deselecting and record mode was
+       * automatically
+       * set when the track was selected, turn
+       * these off */
+      else if (!select &&
+               ch->record_set_automatically)
+        {
+          track_set_recording (self, 0);
+          ch->record_set_automatically = 0;
+        }
+      break;
+    case TRACK_TYPE_CHORD:
+    case TRACK_TYPE_MASTER:
+    case TRACK_TYPE_AUDIO_BUS:
+    case TRACK_TYPE_AUDIO_GROUP:
+    case TRACK_TYPE_MIDI_BUS:
+    case TRACK_TYPE_MIDI_GROUP:
+      break;
+    default:
+      break;
+    }
+
+  if (fire_events)
+    {
+      EVENTS_PUSH (ET_TRACK_CHANGED,
+                   self);
+    }
+}
+
 /**
  * Sets recording and connects/disconnects the JACK ports.
  */
@@ -695,7 +781,8 @@ track_set_pos (
 
   for (int i = 0; i < track->num_lanes; i++)
     {
-      track->lanes[i]->track_pos = pos;
+      track_lane_set_track_pos (
+        track->lanes[i], pos);
     }
   automation_tracklist_update_track_pos (
     &track->automation_tracklist, track);
@@ -703,38 +790,15 @@ track_set_pos (
   /* update port identifier track positions */
   if (track->channel)
     {
-      Channel * ch = track->channel;
+      Port * ports[80000];
+      int    num_ports = 0;
+      channel_append_all_ports (
+        track->channel,
+        ports, &num_ports, 1);
 
-      if (track->in_signal_type ==
-            TYPE_AUDIO)
+      for (int i = 0; i < num_ports; i++)
         {
-          ch->stereo_in->l->identifier.track_pos =
-            pos;
-          ch->stereo_in->r->identifier.track_pos =
-            pos;
-        }
-      if (track->in_signal_type ==
-            TYPE_EVENT)
-        {
-          ch->midi_in->identifier.track_pos =
-            pos;
-          if (track_has_piano_roll (track))
-            ch->piano_roll->identifier.track_pos =
-              pos;
-        }
-      if (track->out_signal_type ==
-            TYPE_AUDIO)
-        {
-          ch->stereo_out->l->identifier.track_pos =
-            pos;
-          ch->stereo_out->r->identifier.track_pos =
-            pos;
-        }
-      if (track->out_signal_type ==
-            TYPE_EVENT)
-        {
-          ch->midi_out->identifier.track_pos =
-            pos;
+          ports[i]->identifier.track_pos = pos;
         }
     }
 }
