@@ -90,8 +90,8 @@ draw_cb (
   const float real_val = GET_REAL_VAL;
 
   /* get absolute values in pixels */
-  const float min_px = 0.f;
-  const float max_px = width;
+  /*const float min_px = 0.f;*/
+  /*const float max_px = width;*/
   const float zero_px =
     ((real_zero - real_min) /
      (real_max - real_min)) *
@@ -142,7 +142,7 @@ draw_cb (
   cairo_set_source_rgba (cr, 1, 1, 1, 1);
   z_cairo_get_text_extents_for_widget_full (
     GTK_WIDGET (self), str, &we, NULL,
-    Z_CAIRO_FONT);
+    Z_CAIRO_FONT, PANGO_ELLIPSIZE_NONE, -1);
   if (width < we)
     {
       gtk_widget_set_size_request (
@@ -151,8 +151,9 @@ draw_cb (
         height);
     }
   z_cairo_draw_text_full (
-    cr, str, width / 2 - we / 2,
-    Z_CAIRO_TEXT_PADDING, Z_CAIRO_FONT);
+    cr, widget, str, width / 2 - we / 2,
+    Z_CAIRO_TEXT_PADDING, Z_CAIRO_FONT,
+    PANGO_ELLIPSIZE_NONE, -1);
 
   if (self->hover)
     {
