@@ -617,9 +617,6 @@ on_motion (
       gtk_widget_set_state_flags (
         GTK_WIDGET (self),
         GTK_STATE_FLAG_PRELIGHT, 0);
-      bot_bar_change_status (
-        _("Channel Slot - Double click to open "
-          "plugin - Click and drag to move plugin"));
     }
   else if (gdk_event_get_event_type (event) ==
              GDK_LEAVE_NOTIFY)
@@ -627,7 +624,6 @@ on_motion (
       gtk_widget_unset_state_flags (
         GTK_WIDGET (self),
         GTK_STATE_FLAG_PRELIGHT);
-      bot_bar_change_status ("");
     }
 
   return FALSE;
