@@ -32,7 +32,7 @@
 #include "audio/automation_track.h"
 #include "audio/automation_tracklist.h"
 #include "audio/audio_track.h"
-#include "audio/bus_track.h"
+#include "audio/audio_bus_track.h"
 #include "audio/channel.h"
 #include "audio/chord_object.h"
 #include "audio/chord_region.h"
@@ -272,8 +272,8 @@ chord_arranger_widget_select_all (
   for (int i = 0; i < r->num_chord_objects; i++)
     {
       chord = r->chord_objects[i];
-      chord_object_widget_select (
-        chord->widget, select);
+      chord_object_select (
+        chord, select);
     }
 }
 
