@@ -20,7 +20,8 @@
 #include "gui/backend/events.h"
 #include "gui/backend/tracklist_selections.h"
 #include "gui/widgets/inspector_track.h"
-#include "gui/widgets/instrument_track_info_expander.h"
+#include "gui/widgets/track_input_expander.h"
+#include "gui/widgets/track_properties_expander.h"
 #include "gui/widgets/ports_expander.h"
 #include "project.h"
 #include "utils/resources.h"
@@ -44,51 +45,66 @@ inspector_track_widget_show_tracks (
     {
       track = tls->tracks[0];
 
-      instrument_track_info_expander_widget_setup (
+      track_properties_expander_widget_setup (
         self->instrument_track_info,
         track);
 
+      gtk_widget_set_visible (
+        GTK_WIDGET (self->sends), 0);
+      gtk_widget_set_visible (
+        GTK_WIDGET (self->inputs), 0);
+      /*gtk_widget_set_visible (*/
+        /*GTK_WIDGET (self->stereo_in), 0);*/
+      /*gtk_widget_set_visible (*/
+        /*GTK_WIDGET (self->midi_in), 0);*/
+      /*gtk_widget_set_visible (*/
+        /*GTK_WIDGET (self->midi_out), 0);*/
+
       if (track->channel)
         {
           gtk_widget_set_visible (
-            GTK_WIDGET (self->prefader_sends), 1);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->postfader_sends), 1);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->stereo_in), 1);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->midi_in), 1);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->midi_out), 1);
+            GTK_WIDGET (self->sends), 1);
+
+          if (track_has_inputs (track))
+            {
+              gtk_widget_set_visible (
+                GTK_WIDGET (self->inputs), 1);
+              track_input_expander_widget_refresh (
+                self->inputs, track);
+            }
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->stereo_in), 1);*/
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->midi_in), 1);*/
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->midi_out), 1);*/
 
           ports_expander_widget_setup_track (
-            self->prefader_sends,
-            track, PE_TRACK_PORT_TYPE_PREFADER);
-          ports_expander_widget_setup_track (
-            self->postfader_sends,
-            track, PE_TRACK_PORT_TYPE_POSTFADER);
-          ports_expander_widget_setup_track (
-            self->stereo_in,
-            track, PE_TRACK_PORT_TYPE_STEREO_IN);
-          ports_expander_widget_setup_track (
-            self->midi_in,
-            track, PE_TRACK_PORT_TYPE_MIDI_IN);
-          ports_expander_widget_setup_track (
-            self->midi_out,
-            track, PE_TRACK_PORT_TYPE_MIDI_OUT);
+            self->sends,
+            track, PE_TRACK_PORT_TYPE_SENDS);
+
+          /*ports_expander_widget_setup_track (*/
+            /*self->stereo_in,*/
+            /*track, PE_TRACK_PORT_TYPE_STEREO_IN);*/
+          /*ports_expander_widget_setup_track (*/
+            /*self->midi_in,*/
+            /*track, PE_TRACK_PORT_TYPE_MIDI_IN);*/
+          /*ports_expander_widget_setup_track (*/
+            /*self->midi_out,*/
+            /*track, PE_TRACK_PORT_TYPE_MIDI_OUT);*/
         }
       else
         {
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->prefader_sends), 0);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->postfader_sends), 0);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->stereo_in), 0);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->midi_in), 0);
-          gtk_widget_set_visible (
-            GTK_WIDGET (self->midi_out), 0);
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->prefader_sends), 0);*/
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->postfader_sends), 0);*/
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->stereo_in), 0);*/
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->midi_in), 0);*/
+          /*gtk_widget_set_visible (*/
+            /*GTK_WIDGET (self->midi_out), 0);*/
         }
     }
 }
@@ -109,11 +125,8 @@ inspector_track_widget_class_init (
     child);
 
   BIND_CHILD (instrument_track_info);
-  BIND_CHILD (prefader_sends);
-  BIND_CHILD (postfader_sends);
-  BIND_CHILD (stereo_in);
-  BIND_CHILD (midi_in);
-  BIND_CHILD (midi_out);
+  BIND_CHILD (sends);
+  BIND_CHILD (inputs);
 
 #undef BIND_CHILD
 }
@@ -123,7 +136,9 @@ inspector_track_widget_init (
   InspectorTrackWidget * self)
 {
   g_type_ensure (
-    INSTRUMENT_TRACK_INFO_EXPANDER_WIDGET_TYPE);
+    TRACK_PROPERTIES_EXPANDER_WIDGET_TYPE);
+  g_type_ensure (
+    TRACK_INPUT_EXPANDER_WIDGET_TYPE);
 
   gtk_widget_init_template (GTK_WIDGET (self));
 }
