@@ -24,7 +24,9 @@
 #include "gui/widgets/bot_dock_edge.h"
 #include "gui/widgets/center_dock.h"
 #include "gui/widgets/clip_editor.h"
+#include "gui/widgets/clip_editor_inner.h"
 #include "gui/widgets/midi_arranger.h"
+#include "gui/widgets/midi_editor_space.h"
 #include "gui/widgets/midi_modifier_arranger.h"
 #include "gui/widgets/midi_note.h"
 #include "gui/widgets/ruler.h"
@@ -124,7 +126,7 @@ midi_modifier_arranger_widget_select (
       Velocity * vel =
         vel_w->velocity;
       ARRANGER_WIDGET_SELECT_MIDI_NOTE (
-        MIDI_ARRANGER,
+        MW_MIDI_ARRANGER,
         vel->midi_note,
         1,
         1);
@@ -150,10 +152,10 @@ midi_modifier_arranger_widget_get_hit_velocity (
 }
 
 void
-midi_modifier_arranger_on_drag_begin_vel_hit (
+midi_modifier_arranger_widget_on_drag_begin_velocity_hit (
   MidiModifierArrangerWidget * self,
-  VelocityWidget *             vel_w,
-  double                       start_y)
+  double                       start_y,
+  VelocityWidget *             vel_w)
 {
   ARRANGER_WIDGET_GET_PRIVATE (self);
 
@@ -219,9 +221,10 @@ midi_modifier_arranger_widget_select_all (
  */
 void
 midi_modifier_arranger_widget_show_context_menu (
-  MidiModifierArrangerWidget * self)
+  MidiModifierArrangerWidget * self,
+  double                       x,
+  double                       y)
 {
-
   /* TODO */
 }
 
@@ -238,13 +241,13 @@ midi_modifier_arranger_widget_ramp (
   ARRANGER_WIDGET_GET_PRIVATE (self);
 
   Position selection_start_pos, selection_end_pos;
-  ui_px_to_pos_piano_roll (
+  ui_px_to_pos_editor (
     ar_prv->start_x,
     offset_x >= 0 ?
       &selection_start_pos :
       &selection_end_pos,
     F_PADDING);
-  ui_px_to_pos_piano_roll (
+  ui_px_to_pos_editor (
     ar_prv->start_x + offset_x,
     offset_x >= 0 ?
       &selection_end_pos :
@@ -279,7 +282,7 @@ midi_modifier_arranger_widget_ramp (
       midi_note_get_global_start_pos (
         vel->midi_note, &start_pos);
       px =
-        ui_pos_to_px_piano_roll (
+        ui_pos_to_px_editor (
           &start_pos, F_PADDING);
 
       x1 = ar_prv->start_x;
@@ -433,13 +436,13 @@ midi_modifier_arranger_widget_on_drag_end (
       {
         Position selection_start_pos,
                  selection_end_pos;
-        ui_px_to_pos_piano_roll (
+        ui_px_to_pos_editor (
           ar_prv->start_x,
           ar_prv->last_offset_x >= 0 ?
             &selection_start_pos :
             &selection_end_pos,
           F_PADDING);
-        ui_px_to_pos_piano_roll (
+        ui_px_to_pos_editor (
           ar_prv->start_x + ar_prv->last_offset_x,
           ar_prv->last_offset_x >= 0 ?
             &selection_end_pos :
