@@ -188,9 +188,6 @@ midi_track_widget_init (
   gtk_widget_set_tooltip_text (
     GTK_WIDGET (self->record),
     _("Record"));
-  ui_set_hover_status_bar_signals (
-    self->record,
-    "Record - Arm track for recording");
   context =
     gtk_widget_get_style_context (
       GTK_WIDGET (self->record));
@@ -202,9 +199,6 @@ midi_track_widget_init (
       "solo.svg");
   gtk_widget_set_tooltip_text (
     GTK_WIDGET (self->solo), "Solo");
-  ui_set_hover_status_bar_signals (
-    self->solo,
-    "Solo - Mutes any unsoloed tracks");
   context =
     gtk_widget_get_style_context (
       GTK_WIDGET (self->solo));
@@ -216,48 +210,30 @@ midi_track_widget_init (
       "mute.svg");
   gtk_widget_set_tooltip_text (
     GTK_WIDGET (self->mute), "Mute");
-  ui_set_hover_status_bar_signals (
-    self->mute,
-    "Mute - Silences the track");
   self->show_automation =
     z_gtk_toggle_button_new_with_icon (
       "z-node-type-cusp");
   ui_add_widget_tooltip (
     self->show_automation,
     _("Show automation lanes"));
-  ui_set_hover_status_bar_signals (
-    self->show_automation,
-    "Show Automation Lanes - Shows the track's "
-    "automation lanes"
-    "UI");
   self->show_lanes =
     z_gtk_toggle_button_new_with_icon (
       "z-format-justify-fill");
   ui_add_widget_tooltip (
     self->show_lanes,
     _("Show track lanes"));
-  ui_set_hover_status_bar_signals (
-    self->show_lanes,
-    _("Show Lanes - Shows the track's lanes"));
   self->lock =
     z_gtk_toggle_button_new_with_icon (
       "z-object-unlocked");
   gtk_widget_set_tooltip_text (
     GTK_WIDGET (self->lock),
     _("Lock track"));
-  ui_set_hover_status_bar_signals (
-    self->lock,
-    "Lock - Makes the track uneditable");
   self->freeze =
     z_gtk_toggle_button_new_with_icon (
       "snowflake-o");
   gtk_widget_set_tooltip_text (
     GTK_WIDGET (self->freeze),
     _("Freeze track"));
-  ui_set_hover_status_bar_signals (
-    self->freeze,
-    "Freeze - Freezes (bounces to audio) the track "
-    "- Useful for conserving CPU/DSP consumption");
 
   /* set buttons to upper controls */
   gtk_box_pack_start (
