@@ -202,6 +202,26 @@ plugin_add_automation_track (
   automation_tracklist_add_at (atl, at);
 }
 
+/**
+ * Updates the plugin's latency.
+ *
+ * Calls the plugin format's get_latency()
+ * function and stores the result in the plugin.
+ */
+void
+plugin_update_latency (
+  Plugin * pl)
+{
+  if (pl->descr->protocol == PROT_LV2)
+    {
+      pl->latency =
+        lv2_plugin_get_latency (pl->lv2);
+      g_message ("%s latency: %d samples",
+                 pl->descr->name,
+                 pl->latency);
+    }
+}
+
 /**
  * Loads the plugin from its state file.
  */
@@ -588,12 +608,17 @@ plugin_instantiate (
 }
 
 /**
- * Process plugin
+ * Process plugin.
+ *
+ * @param g_start_frames The global start frames.
+ * @param nframes The number of frames to process.
  */
 void
-plugin_process (Plugin * plugin)
+plugin_process (
+  Plugin *    plugin,
+  const long  g_start_frames,
+  const int   nframes)
 {
-
   /* if has MIDI input port */
   if (plugin->descr->num_midi_ins > 0)
     {
@@ -606,7 +631,7 @@ plugin_process (Plugin * plugin)
   if (plugin->descr->protocol == PROT_LV2)
     {
       lv2_plugin_process (
-        (Lv2Plugin *) plugin->lv2);
+        plugin->lv2, g_start_frames, nframes);
     }
 
   /*g_atomic_int_set (&plugin->processed, 1);*/
