@@ -48,6 +48,7 @@
 #include "gui/widgets/track.h"
 #include "plugins/lv2_plugin.h"
 #include "utils/arrays.h"
+#include "utils/datetime.h"
 #include "utils/general.h"
 #include "utils/flags.h"
 #include "utils/io.h"
@@ -321,6 +322,9 @@ load (char * filename)
         }
     }
 
+  tracklist_init_loaded (&PROJECT->tracklist);
+  clip_editor_init_loaded (CLIP_EDITOR);
+
   /* init ports */
   Port * ports[10000];
   int num_ports;
@@ -334,9 +338,6 @@ load (char * filename)
                  port->identifier.label);
     }
 
-  tracklist_init_loaded (&PROJECT->tracklist);
-  clip_editor_init_loaded (CLIP_EDITOR);
-
   timeline_selections_init_loaded (
     &PROJECT->timeline_selections);
   midi_arranger_selections_init_loaded (
@@ -388,10 +389,25 @@ int
 project_load (char * filename)
 {
   if (filename)
-    return load (filename);
+    load (filename);
   else
     create_default (PROJECT);
 
+  engine_activate (AUDIO_ENGINE);
+
+  /* connect channel inputs to hardware. has to
+   * be done after engine activation */
+  Channel *ch;
+  for (int i = 0; i < TRACKLIST->num_tracks; i++)
+    {
+      ch = TRACKLIST->tracks[i]->channel;
+      if (!ch)
+        continue;
+
+      channel_reconnect_ext_input_ports (
+        ch);
+    }
+
   /* set the version */
   PROJECT->version =
     zrythm_get_version (0);
@@ -411,7 +427,9 @@ project_set_has_range (int has_range)
 }
 
 int
-project_save (const char * dir)
+project_save (
+  Project * self,
+  const char * dir)
 {
   int i, j;
 
@@ -419,6 +437,12 @@ project_save (const char * dir)
   update_paths (dir);
   PROJECT->title = io_path_get_basename (dir);
 
+  /* save current datetime */
+  if (self->datetime_str)
+    g_free (self->datetime_str);
+  PROJECT->datetime_str =
+    datetime_get_current_as_string ();
+
   /*smf_save_regions ();*/
 
   /* write plugin states, prepare channels for
