@@ -17,7 +17,8 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include "zrythm.h"
+#include "config.h"
+
 #include "actions/actions.h"
 #include "actions/undo_manager.h"
 #include "audio/engine.h"
@@ -41,6 +42,7 @@
 #include "utils/localization.h"
 #include "utils/log.h"
 #include "utils/io.h"
+#include "zrythm.h"
 
 #include "Wrapper.h"
 
@@ -527,6 +529,36 @@ static void on_prompt_for_project (GSimpleAction  *action,
     }
 }
 
+/**
+ * Returns the version string.
+ *
+ * Must be g_free()'d.
+ *
+ * @param with_v Include a starting "v".
+ */
+char *
+zrythm_get_version (
+  int with_v)
+{
+  char * ver = PACKAGE_VERSION;
+
+  if (with_v)
+    {
+      if (ver[0] == 'v')
+        return g_strdup (ver);
+      else
+        return
+          g_strdup_printf ("v%s", ver);
+    }
+  else
+    {
+      if (ver[0] == 'v')
+        return g_strdup (ver + 1);
+      else
+        return g_strdup (ver);
+    }
+}
+
 /*
  * Called after startup if no filename is passed on command
  * line.
@@ -572,6 +604,56 @@ zrythm_app_startup (GApplication* _app)
 
   app = _app;
 
+  /* set theme */
+  g_object_set (gtk_settings_get_default (),
+                "gtk-theme-name",
+                "Matcha-dark-sea",
+                NULL);
+  g_message ("set theme");
+
+  /*g_object_set (gtk_settings_get_default (),*/
+                /*"gtk-icon-theme-name",*/
+                /*"breeze-dark",*/
+                /*NULL);*/
+
+  gtk_icon_theme_add_resource_path (
+    gtk_icon_theme_get_default (),
+    "/org/zrythm/Zrythm/app/icons/breeze-icons");
+  gtk_icon_theme_add_resource_path (
+    gtk_icon_theme_get_default (),
+    "/org/zrythm/Zrythm/app/icons/fork-awesome");
+  gtk_icon_theme_add_resource_path (
+    gtk_icon_theme_get_default (),
+    "/org/zrythm/Zrythm/app/icons/font-awesome");
+  gtk_icon_theme_add_resource_path (
+    gtk_icon_theme_get_default (),
+    "/org/zrythm/Zrythm/app/icons/zrythm");
+  gtk_icon_theme_add_resource_path (
+    gtk_icon_theme_get_default (),
+    "/org/zrythm/Zrythm/app/icons/ext");
+  gtk_icon_theme_add_resource_path (
+    gtk_icon_theme_get_default (),
+    "/org/zrythm/Zrythm/app/icons/gnome-builder");
+
+  /*gtk_icon_theme_set_search_path (*/
+    /*gtk_icon_theme_get_default (),*/
+    /*path,*/
+    /*1);*/
+  g_message ("set resource paths");
+
+  // set default css provider
+  GtkCssProvider * css_provider =
+    gtk_css_provider_new();
+  gtk_css_provider_load_from_resource (
+    css_provider,
+    "/org/zrythm/Zrythm/app/theme.css");
+  gtk_style_context_add_provider_for_screen (
+          gdk_screen_get_default (),
+          GTK_STYLE_PROVIDER (css_provider),
+          800);
+  g_object_unref (css_provider);
+  g_message ("set default css provider");
+
   /* show splash screen */
   splash =
     splash_window_widget_new (ZRYTHM_APP (app));
@@ -749,7 +831,6 @@ zrythm_app_init (ZrythmApp *app)
     { "fullscreen", activate_fullscreen },
     { "chat", activate_chat },
     { "manual", activate_manual },
-    { "forums", activate_forums },
     { "bugreport", activate_bugreport },
     { "donate", activate_donate },
     { "iconify", activate_iconify },
